Psi Swarm robot library version 0.9

Dependents:   PsiSwarm_V9_Blank

Fork of PsiSwarmV9 by James Hilder

Revision:
15:66be5ec52c3b
Parent:
12:878c6e9d9e60
Child:
16:50686c07ad07
--- a/display.h	Tue May 30 21:03:18 2017 +0000
+++ b/display.h	Thu Jun 01 21:58:14 2017 +0000
@@ -116,6 +116,11 @@
     */
     void set_backlight_brightness(float brightness);
 
+    /** Display the switch state at the current cursor position
+    * @param switch_state - The value of the cursor switch (range 0 to 31)
+    */
+    void show_switch_state(char switch_state);
+    
     // Special function for when debug messages are sent to display
     void debug_page(char * message, char length);
 
@@ -135,8 +140,11 @@
     // Send a 1-byte control message to the display
     int i2c_message(char byte);
 
-    // Default initialisation sequence for the display
-    void init_display(char mode);
+    // Default initialisation sequence for the display (start of boot)
+    void init_display_start();
+
+    // Default initialisation sequence for the display (end of boot)
+    void init_display_end(char mode);
 
     int disp_putc(int c);